PyMetaWear contributors (sorted alphabetically)
===============================================

* [Jonas Böer](https://github.com/morgil) (Kinemic GmbH)
    - Magnetometer module
    
* [Eric Tsai](https://github.com/scaryghost) (mbientlab)
    - 64-bit datasignal address handling and typecasting
